"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateDescribeCustomKeyStores = void 0;
const DescribeCustomKeyStoresCommand_1 = require("../commands/DescribeCustomKeyStoresCommand");
const KMSClient_1 = require("../KMSClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new DescribeCustomKeyStoresCommand_1.DescribeCustomKeyStoresCommand(input), ...args);
};
async function* paginateDescribeCustomKeyStores(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.Marker = token;
        input["Limit"] = config.pageSize;
        if (config.client instanceof KMSClient_1.KMSClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected KMS | KMSClient");
        }
        yield page;
        const prevToken = token;
        token = page.NextMarker;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateDescribeCustomKeyStores = paginateDescribeCustomKeyStores;
