/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
import { __awaiter } from "tslib";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { ComputeManagementClient } from "@azure/arm-compute";
import { DefaultAzureCredential } from "@azure/identity";
import * as dotenv from "dotenv";
dotenv.config();
/**
 * This sample demonstrates how to Creates or updates a disk encryption set
 *
 * @summary Creates or updates a disk encryption set
 * x-ms-original-file: specification/compute/resource-manager/Microsoft.Compute/DiskRP/stable/2022-07-02/examples/diskEncryptionSetExamples/DiskEncryptionSet_Create_WithKeyVaultFromADifferentSubscription.json
 */
function createADiskEncryptionSetWithKeyVaultFromADifferentSubscription() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = process.env["COMPUTE_SUBSCRIPTION_ID"] || "{subscription-id}";
        const resourceGroupName = process.env["COMPUTE_RESOURCE_GROUP"] || "myResourceGroup";
        const diskEncryptionSetName = "myDiskEncryptionSet";
        const diskEncryptionSet = {
            activeKey: {
                keyUrl: "https://myvaultdifferentsub.vault-int.azure-int.net/keys/{key}"
            },
            encryptionType: "EncryptionAtRestWithCustomerKey",
            identity: { type: "SystemAssigned" },
            location: "West US"
        };
        const credential = new DefaultAzureCredential();
        const client = new ComputeManagementClient(credential, subscriptionId);
        const result = yield client.diskEncryptionSets.beginCreateOrUpdateAndWait(resourceGroupName, diskEncryptionSetName, diskEncryptionSet);
        console.log(result);
    });
}
/**
 * This sample demonstrates how to Creates or updates a disk encryption set
 *
 * @summary Creates or updates a disk encryption set
 * x-ms-original-file: specification/compute/resource-manager/Microsoft.Compute/DiskRP/stable/2022-07-02/examples/diskEncryptionSetExamples/DiskEncryptionSet_Create_WithKeyVaultFromADifferentTenant.json
 */
function createADiskEncryptionSetWithKeyVaultFromADifferentTenant() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = process.env["COMPUTE_SUBSCRIPTION_ID"] || "{subscription-id}";
        const resourceGroupName = process.env["COMPUTE_RESOURCE_GROUP"] || "myResourceGroup";
        const diskEncryptionSetName = "myDiskEncryptionSet";
        const diskEncryptionSet = {
            activeKey: {
                keyUrl: "https://myvaultdifferenttenant.vault-int.azure-int.net/keys/{key}"
            },
            encryptionType: "EncryptionAtRestWithCustomerKey",
            federatedClientId: "00000000-0000-0000-0000-000000000000",
            identity: {
                type: "UserAssigned",
                userAssignedIdentities: {
                    "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/MicrosoftManagedIdentity/userAssignedIdentities/{identityName}": {}
                }
            },
            location: "West US"
        };
        const credential = new DefaultAzureCredential();
        const client = new ComputeManagementClient(credential, subscriptionId);
        const result = yield client.diskEncryptionSets.beginCreateOrUpdateAndWait(resourceGroupName, diskEncryptionSetName, diskEncryptionSet);
        console.log(result);
    });
}
/**
 * This sample demonstrates how to Creates or updates a disk encryption set
 *
 * @summary Creates or updates a disk encryption set
 * x-ms-original-file: specification/compute/resource-manager/Microsoft.Compute/DiskRP/stable/2022-07-02/examples/diskEncryptionSetExamples/DiskEncryptionSet_Create.json
 */
function createADiskEncryptionSet() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = process.env["COMPUTE_SUBSCRIPTION_ID"] || "{subscription-id}";
        const resourceGroupName = process.env["COMPUTE_RESOURCE_GROUP"] || "myResourceGroup";
        const diskEncryptionSetName = "myDiskEncryptionSet";
        const diskEncryptionSet = {
            activeKey: {
                keyUrl: "https://myvmvault.vault-int.azure-int.net/keys/{key}",
                sourceVault: {
                    id: "/subscriptions/{subscriptionId}/resourceGroups/myResourceGroup/providers/Microsoft.KeyVault/vaults/myVMVault"
                }
            },
            encryptionType: "EncryptionAtRestWithCustomerKey",
            identity: { type: "SystemAssigned" },
            location: "West US"
        };
        const credential = new DefaultAzureCredential();
        const client = new ComputeManagementClient(credential, subscriptionId);
        const result = yield client.diskEncryptionSets.beginCreateOrUpdateAndWait(resourceGroupName, diskEncryptionSetName, diskEncryptionSet);
        console.log(result);
    });
}
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        createADiskEncryptionSetWithKeyVaultFromADifferentSubscription();
        createADiskEncryptionSetWithKeyVaultFromADifferentTenant();
        createADiskEncryptionSet();
    });
}
main().catch(console.error);
//# sourceMappingURL=diskEncryptionSetsCreateOrUpdateSample.js.map