/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
import { __awaiter } from "tslib";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { ComputeManagementClient } from "@azure/arm-compute";
import { DefaultAzureCredential } from "@azure/identity";
import * as dotenv from "dotenv";
dotenv.config();
/**
 * This sample demonstrates how to The operation to update a virtual machine.
 *
 * @summary The operation to update a virtual machine.
 * x-ms-original-file: specification/compute/resource-manager/Microsoft.Compute/ComputeRP/stable/2022-11-01/examples/virtualMachineExamples/VirtualMachine_Update_DetachDataDiskUsingToBeDetachedProperty.json
 */
function updateAVMByDetachingDataDisk() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = process.env["COMPUTE_SUBSCRIPTION_ID"] || "{subscription-id}";
        const resourceGroupName = process.env["COMPUTE_RESOURCE_GROUP"] || "myResourceGroup";
        const vmName = "myVM";
        const parameters = {
            hardwareProfile: { vmSize: "Standard_D2_v2" },
            networkProfile: {
                networkInterfaces: [
                    {
                        id: "/subscriptions/{subscription-id}/resourceGroups/myResourceGroup/providers/Microsoft.Network/networkInterfaces/{existing-nic-name}",
                        primary: true
                    }
                ]
            },
            osProfile: {
                adminPassword: "{your-password}",
                adminUsername: "{your-username}",
                computerName: "myVM"
            },
            storageProfile: {
                dataDisks: [
                    { createOption: "Empty", diskSizeGB: 1023, lun: 0, toBeDetached: true },
                    { createOption: "Empty", diskSizeGB: 1023, lun: 1, toBeDetached: false }
                ],
                imageReference: {
                    offer: "WindowsServer",
                    publisher: "MicrosoftWindowsServer",
                    sku: "2016-Datacenter",
                    version: "latest"
                },
                osDisk: {
                    name: "myVMosdisk",
                    caching: "ReadWrite",
                    createOption: "FromImage",
                    managedDisk: { storageAccountType: "Standard_LRS" }
                }
            }
        };
        const credential = new DefaultAzureCredential();
        const client = new ComputeManagementClient(credential, subscriptionId);
        const result = yield client.virtualMachines.beginUpdateAndWait(resourceGroupName, vmName, parameters);
        console.log(result);
    });
}
/**
 * This sample demonstrates how to The operation to update a virtual machine.
 *
 * @summary The operation to update a virtual machine.
 * x-ms-original-file: specification/compute/resource-manager/Microsoft.Compute/ComputeRP/stable/2022-11-01/examples/virtualMachineExamples/VirtualMachine_Update_ForceDetachDataDisk.json
 */
function updateAVMByForceDetachingDataDisk() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = process.env["COMPUTE_SUBSCRIPTION_ID"] || "{subscription-id}";
        const resourceGroupName = process.env["COMPUTE_RESOURCE_GROUP"] || "myResourceGroup";
        const vmName = "myVM";
        const parameters = {
            hardwareProfile: { vmSize: "Standard_D2_v2" },
            networkProfile: {
                networkInterfaces: [
                    {
                        id: "/subscriptions/{subscription-id}/resourceGroups/myResourceGroup/providers/Microsoft.Network/networkInterfaces/{existing-nic-name}",
                        primary: true
                    }
                ]
            },
            osProfile: {
                adminPassword: "{your-password}",
                adminUsername: "{your-username}",
                computerName: "myVM"
            },
            storageProfile: {
                dataDisks: [
                    {
                        createOption: "Empty",
                        detachOption: "ForceDetach",
                        diskSizeGB: 1023,
                        lun: 0,
                        toBeDetached: true
                    },
                    { createOption: "Empty", diskSizeGB: 1023, lun: 1, toBeDetached: false }
                ],
                imageReference: {
                    offer: "WindowsServer",
                    publisher: "MicrosoftWindowsServer",
                    sku: "2016-Datacenter",
                    version: "latest"
                },
                osDisk: {
                    name: "myVMosdisk",
                    caching: "ReadWrite",
                    createOption: "FromImage",
                    managedDisk: { storageAccountType: "Standard_LRS" }
                }
            }
        };
        const credential = new DefaultAzureCredential();
        const client = new ComputeManagementClient(credential, subscriptionId);
        const result = yield client.virtualMachines.beginUpdateAndWait(resourceGroupName, vmName, parameters);
        console.log(result);
    });
}
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        updateAVMByDetachingDataDisk();
        updateAVMByForceDetachingDataDisk();
    });
}
main().catch(console.error);
//# sourceMappingURL=virtualMachinesUpdateSample.js.map