import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { CloudServiceRoles } from "../operationsInterfaces";
import { ComputeManagementClient } from "../computeManagementClient";
import { CloudServiceRole, CloudServiceRolesListOptionalParams, CloudServiceRolesGetOptionalParams, CloudServiceRolesGetResponse } from "../models";
/** Class containing CloudServiceRoles operations. */
export declare class CloudServiceRolesImpl implements CloudServiceRoles {
    private readonly client;
    /**
     * Initialize a new instance of the class CloudServiceRoles class.
     * @param client Reference to the service client
     */
    constructor(client: ComputeManagementClient);
    /**
     * Gets a list of all roles in a cloud service. Use nextLink property in the response to get the next
     * page of roles. Do this till nextLink is null to fetch all the roles.
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param options The options parameters.
     */
    list(resourceGroupName: string, cloudServiceName: string, options?: CloudServiceRolesListOptionalParams): PagedAsyncIterableIterator<CloudServiceRole>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Gets a role from a cloud service.
     * @param roleName Name of the role.
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param options The options parameters.
     */
    get(roleName: string, resourceGroupName: string, cloudServiceName: string, options?: CloudServiceRolesGetOptionalParams): Promise<CloudServiceRolesGetResponse>;
    /**
     * Gets a list of all roles in a cloud service. Use nextLink property in the response to get the next
     * page of roles. Do this till nextLink is null to fetch all the roles.
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param options The options parameters.
     */
    private _list;
    /**
     * ListNext
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=cloudServiceRoles.d.ts.map