import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { CommunityGalleryImageVersions } from "../operationsInterfaces";
import { ComputeManagementClient } from "../computeManagementClient";
import { CommunityGalleryImageVersion, CommunityGalleryImageVersionsListOptionalParams, CommunityGalleryImageVersionsGetOptionalParams, CommunityGalleryImageVersionsGetResponse } from "../models";
/** Class containing CommunityGalleryImageVersions operations. */
export declare class CommunityGalleryImageVersionsImpl implements CommunityGalleryImageVersions {
    private readonly client;
    /**
     * Initialize a new instance of the class CommunityGalleryImageVersions class.
     * @param client Reference to the service client
     */
    constructor(client: ComputeManagementClient);
    /**
     * List community gallery image versions inside an image.
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param galleryImageName The name of the community gallery image definition.
     * @param options The options parameters.
     */
    list(location: string, publicGalleryName: string, galleryImageName: string, options?: CommunityGalleryImageVersionsListOptionalParams): PagedAsyncIterableIterator<CommunityGalleryImageVersion>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Get a community gallery image version.
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param galleryImageName The name of the community gallery image definition.
     * @param galleryImageVersionName The name of the community gallery image version. Needs to follow
     *                                semantic version name pattern: The allowed characters are digit and period. Digits must be within
     *                                the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
     * @param options The options parameters.
     */
    get(location: string, publicGalleryName: string, galleryImageName: string, galleryImageVersionName: string, options?: CommunityGalleryImageVersionsGetOptionalParams): Promise<CommunityGalleryImageVersionsGetResponse>;
    /**
     * List community gallery image versions inside an image.
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param galleryImageName The name of the community gallery image definition.
     * @param options The options parameters.
     */
    private _list;
    /**
     * ListNext
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param galleryImageName The name of the community gallery image definition.
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=communityGalleryImageVersions.d.ts.map