import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { CommunityGalleryImages } from "../operationsInterfaces";
import { ComputeManagementClient } from "../computeManagementClient";
import { CommunityGalleryImage, CommunityGalleryImagesListOptionalParams, CommunityGalleryImagesGetOptionalParams, CommunityGalleryImagesGetResponse } from "../models";
/** Class containing CommunityGalleryImages operations. */
export declare class CommunityGalleryImagesImpl implements CommunityGalleryImages {
    private readonly client;
    /**
     * Initialize a new instance of the class CommunityGalleryImages class.
     * @param client Reference to the service client
     */
    constructor(client: ComputeManagementClient);
    /**
     * List community gallery images inside a gallery.
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param options The options parameters.
     */
    list(location: string, publicGalleryName: string, options?: CommunityGalleryImagesListOptionalParams): PagedAsyncIterableIterator<CommunityGalleryImage>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Get a community gallery image.
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param galleryImageName The name of the community gallery image definition.
     * @param options The options parameters.
     */
    get(location: string, publicGalleryName: string, galleryImageName: string, options?: CommunityGalleryImagesGetOptionalParams): Promise<CommunityGalleryImagesGetResponse>;
    /**
     * List community gallery images inside a gallery.
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param options The options parameters.
     */
    private _list;
    /**
     * ListNext
     * @param location Resource location.
     * @param publicGalleryName The public name of the community gallery.
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=communityGalleryImages.d.ts.map