import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { MhsmPrivateEndpointConnections } from "../operationsInterfaces";
import { KeyVaultManagementClient } from "../keyVaultManagementClient";
import { PollerLike, PollOperationState } from "@azure/core-lro";
import { MhsmPrivateEndpointConnection, MhsmPrivateEndpointConnectionsListByResourceOptionalParams, MhsmPrivateEndpointConnectionsGetOptionalParams, MhsmPrivateEndpointConnectionsGetResponse, MhsmPrivateEndpointConnectionsPutOptionalParams, MhsmPrivateEndpointConnectionsPutResponse, MhsmPrivateEndpointConnectionsDeleteOptionalParams, MhsmPrivateEndpointConnectionsDeleteResponse } from "../models";
/** Class containing MhsmPrivateEndpointConnections operations. */
export declare class MhsmPrivateEndpointConnectionsImpl implements MhsmPrivateEndpointConnections {
    private readonly client;
    /**
     * Initialize a new instance of the class MhsmPrivateEndpointConnections class.
     * @param client Reference to the service client
     */
    constructor(client: KeyVaultManagementClient);
    /**
     * The List operation gets information about the private endpoint connections associated with the
     * managed HSM Pool.
     * @param resourceGroupName Name of the resource group that contains the managed HSM pool.
     * @param name Name of the managed HSM Pool
     * @param options The options parameters.
     */
    listByResource(resourceGroupName: string, name: string, options?: MhsmPrivateEndpointConnectionsListByResourceOptionalParams): PagedAsyncIterableIterator<MhsmPrivateEndpointConnection>;
    private listByResourcePagingPage;
    private listByResourcePagingAll;
    /**
     * The List operation gets information about the private endpoint connections associated with the
     * managed HSM Pool.
     * @param resourceGroupName Name of the resource group that contains the managed HSM pool.
     * @param name Name of the managed HSM Pool
     * @param options The options parameters.
     */
    private _listByResource;
    /**
     * Gets the specified private endpoint connection associated with the managed HSM Pool.
     * @param resourceGroupName Name of the resource group that contains the managed HSM pool.
     * @param name Name of the managed HSM Pool
     * @param privateEndpointConnectionName Name of the private endpoint connection associated with the
     *                                      managed hsm pool.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, name: string, privateEndpointConnectionName: string, options?: MhsmPrivateEndpointConnectionsGetOptionalParams): Promise<MhsmPrivateEndpointConnectionsGetResponse>;
    /**
     * Updates the specified private endpoint connection associated with the managed hsm pool.
     * @param resourceGroupName Name of the resource group that contains the managed HSM pool.
     * @param name Name of the managed HSM Pool
     * @param privateEndpointConnectionName Name of the private endpoint connection associated with the
     *                                      managed hsm pool.
     * @param properties The intended state of private endpoint connection.
     * @param options The options parameters.
     */
    put(resourceGroupName: string, name: string, privateEndpointConnectionName: string, properties: MhsmPrivateEndpointConnection, options?: MhsmPrivateEndpointConnectionsPutOptionalParams): Promise<MhsmPrivateEndpointConnectionsPutResponse>;
    /**
     * Deletes the specified private endpoint connection associated with the managed hsm pool.
     * @param resourceGroupName Name of the resource group that contains the managed HSM pool.
     * @param name Name of the managed HSM Pool
     * @param privateEndpointConnectionName Name of the private endpoint connection associated with the
     *                                      managed hsm pool.
     * @param options The options parameters.
     */
    beginDelete(resourceGroupName: string, name: string, privateEndpointConnectionName: string, options?: MhsmPrivateEndpointConnectionsDeleteOptionalParams): Promise<PollerLike<PollOperationState<MhsmPrivateEndpointConnectionsDeleteResponse>, MhsmPrivateEndpointConnectionsDeleteResponse>>;
    /**
     * Deletes the specified private endpoint connection associated with the managed hsm pool.
     * @param resourceGroupName Name of the resource group that contains the managed HSM pool.
     * @param name Name of the managed HSM Pool
     * @param privateEndpointConnectionName Name of the private endpoint connection associated with the
     *                                      managed hsm pool.
     * @param options The options parameters.
     */
    beginDeleteAndWait(resourceGroupName: string, name: string, privateEndpointConnectionName: string, options?: MhsmPrivateEndpointConnectionsDeleteOptionalParams): Promise<MhsmPrivateEndpointConnectionsDeleteResponse>;
    /**
     * ListByResourceNext
     * @param resourceGroupName Name of the resource group that contains the managed HSM pool.
     * @param name Name of the managed HSM Pool
     * @param nextLink The nextLink from the previous successful call to the ListByResource method.
     * @param options The options parameters.
     */
    private _listByResourceNext;
}
//# sourceMappingURL=mhsmPrivateEndpointConnections.d.ts.map