/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
import { __awaiter } from "tslib";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { NetworkManagementClient } from "@azure/arm-network";
import { DefaultAzureCredential } from "@azure/identity";
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreate.json
 */
function createLoadBalancer() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [{ name: "be-lb" }],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/vnetlb/subnets/subnetlb"
                    }
                }
            ],
            inboundNatPools: [],
            inboundNatRules: [
                {
                    name: "in-nat-rule",
                    backendPort: 3389,
                    enableFloatingIP: true,
                    enableTcpReset: false,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 3389,
                    idleTimeoutInMinutes: 15,
                    protocol: "Tcp"
                }
            ],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPool: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                    },
                    backendPort: 80,
                    enableFloatingIP: true,
                    enableTcpReset: false,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 80,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "Tcp"
                }
            ],
            location: "eastus",
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ]
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancer().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateWithZones.json
 */
function createLoadBalancerWithFrontendIPInZone1() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [{ name: "be-lb" }],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/vnetlb/subnets/subnetlb"
                    },
                    zones: ["1"]
                }
            ],
            inboundNatPools: [],
            inboundNatRules: [
                {
                    name: "in-nat-rule",
                    backendPort: 3389,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 3389,
                    idleTimeoutInMinutes: 15,
                    protocol: "Tcp"
                }
            ],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPool: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                    },
                    backendPort: 80,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 80,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "Tcp"
                }
            ],
            location: "eastus",
            outboundRules: [],
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ],
            sku: { name: "Standard" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithFrontendIPInZone1().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateGatewayLoadBalancerConsumer.json
 */
function createLoadBalancerWithGatewayLoadBalancerConsumerConfigured() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [{ name: "be-lb" }],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    gatewayLoadBalancer: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb-provider"
                    },
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/vnetlb/subnets/subnetlb"
                    }
                }
            ],
            inboundNatPools: [],
            inboundNatRules: [
                {
                    name: "in-nat-rule",
                    backendPort: 3389,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 3389,
                    idleTimeoutInMinutes: 15,
                    protocol: "Tcp"
                }
            ],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPool: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                    },
                    backendPort: 80,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 80,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "Tcp"
                }
            ],
            location: "eastus",
            outboundRules: [],
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ],
            sku: { name: "Standard" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithGatewayLoadBalancerConsumerConfigured().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateGatewayLoadBalancerProviderWithOneBackendPool.json
 */
function createLoadBalancerWithGatewayLoadBalancerProviderConfiguredWithOneBackendPool() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [
                {
                    name: "be-lb",
                    tunnelInterfaces: [
                        { type: "Internal", identifier: 900, port: 15000, protocol: "VXLAN" },
                        { type: "Internal", identifier: 901, port: 15001, protocol: "VXLAN" }
                    ]
                }
            ],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/vnetlb/subnets/subnetlb"
                    }
                }
            ],
            inboundNatPools: [],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPools: [
                        {
                            id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                        }
                    ],
                    backendPort: 0,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 0,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "All"
                }
            ],
            location: "eastus",
            outboundRules: [],
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ],
            sku: { name: "Premium" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithGatewayLoadBalancerProviderConfiguredWithOneBackendPool().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateGatewayLoadBalancerProviderWithTwoBackendPool.json
 */
function createLoadBalancerWithGatewayLoadBalancerProviderConfiguredWithTwoBackendPool() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [{ name: "be-lb1" }, { name: "be-lb2" }],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/vnetlb/subnets/subnetlb"
                    }
                }
            ],
            inboundNatPools: [],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPool: {},
                    backendAddressPools: [
                        {
                            id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb1"
                        },
                        {
                            id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb2"
                        }
                    ],
                    backendPort: 0,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 0,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "All"
                }
            ],
            location: "eastus",
            outboundRules: [],
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ],
            sku: { name: "Premium" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithGatewayLoadBalancerProviderConfiguredWithTwoBackendPool().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateGlobalTier.json
 */
function createLoadBalancerWithGlobalTierAndOneRegionalLoadBalancerInItsBackendPool() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [
                {
                    name: "be-lb",
                    loadBalancerBackendAddresses: [
                        {
                            name: "regional-lb1-address",
                            loadBalancerFrontendIPConfiguration: {
                                id: "/subscriptions/subid/resourceGroups/regional-lb-rg1/providers/Microsoft.Network/loadBalancers/regional-lb/frontendIPConfigurations/fe-rlb"
                            }
                        }
                    ]
                }
            ],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/vnetlb/subnets/subnetlb"
                    }
                }
            ],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPool: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                    },
                    backendPort: 80,
                    enableFloatingIP: false,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 80,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "Tcp"
                }
            ],
            location: "eastus",
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ],
            sku: { name: "Standard", tier: "Global" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithGlobalTierAndOneRegionalLoadBalancerInItsBackendPool().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateStandardSku.json
 */
function createLoadBalancerWithStandardSku() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [{ name: "be-lb" }],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/vnetlb/subnets/subnetlb"
                    }
                }
            ],
            inboundNatPools: [],
            inboundNatRules: [
                {
                    name: "in-nat-rule",
                    backendPort: 3389,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 3389,
                    idleTimeoutInMinutes: 15,
                    protocol: "Tcp"
                }
            ],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPool: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                    },
                    backendPort: 80,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 80,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "Tcp"
                }
            ],
            location: "eastus",
            outboundRules: [],
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ],
            sku: { name: "Standard" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithStandardSku().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateWithInboundNatPool.json
 */
function createLoadBalancerWithInboundNatPool() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [],
            frontendIPConfigurations: [
                {
                    name: "test",
                    id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/test",
                    privateIPAllocationMethod: "Dynamic",
                    subnet: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/virtualNetworks/lbvnet/subnets/lbsubnet"
                    },
                    zones: []
                }
            ],
            inboundNatPools: [
                {
                    name: "test",
                    backendPort: 8888,
                    enableFloatingIP: true,
                    enableTcpReset: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/test"
                    },
                    frontendPortRangeEnd: 8085,
                    frontendPortRangeStart: 8080,
                    id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/inboundNatPools/test",
                    idleTimeoutInMinutes: 10,
                    protocol: "Tcp"
                }
            ],
            inboundNatRules: [],
            loadBalancingRules: [],
            location: "eastus",
            outboundRules: [],
            probes: [],
            sku: { name: "Standard" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithInboundNatPool().catch(console.error);
/**
 * This sample demonstrates how to Creates or updates a load balancer.
 *
 * @summary Creates or updates a load balancer.
 * x-ms-original-file: specification/network/resource-manager/Microsoft.Network/stable/2022-07-01/examples/LoadBalancerCreateWithOutboundRules.json
 */
function createLoadBalancerWithOutboundRules() {
    return __awaiter(this, void 0, void 0, function* () {
        const subscriptionId = "subid";
        const resourceGroupName = "rg1";
        const loadBalancerName = "lb";
        const parameters = {
            backendAddressPools: [{ name: "be-lb" }],
            frontendIPConfigurations: [
                {
                    name: "fe-lb",
                    publicIPAddress: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/publicIPAddresses/pip"
                    }
                }
            ],
            inboundNatPools: [],
            inboundNatRules: [
                {
                    name: "in-nat-rule",
                    backendPort: 3389,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 3389,
                    idleTimeoutInMinutes: 15,
                    protocol: "Tcp"
                }
            ],
            loadBalancingRules: [
                {
                    name: "rulelb",
                    backendAddressPool: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                    },
                    backendPort: 80,
                    disableOutboundSnat: true,
                    enableFloatingIP: true,
                    frontendIPConfiguration: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                    },
                    frontendPort: 80,
                    idleTimeoutInMinutes: 15,
                    loadDistribution: "Default",
                    probe: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/probes/probe-lb"
                    },
                    protocol: "Tcp"
                }
            ],
            location: "eastus",
            outboundRules: [
                {
                    name: "rule1",
                    backendAddressPool: {
                        id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/backendAddressPools/be-lb"
                    },
                    frontendIPConfigurations: [
                        {
                            id: "/subscriptions/subid/resourceGroups/rg1/providers/Microsoft.Network/loadBalancers/lb/frontendIPConfigurations/fe-lb"
                        }
                    ],
                    protocol: "All"
                }
            ],
            probes: [
                {
                    name: "probe-lb",
                    intervalInSeconds: 15,
                    numberOfProbes: 2,
                    port: 80,
                    probeThreshold: 1,
                    requestPath: "healthcheck.aspx",
                    protocol: "Http"
                }
            ],
            sku: { name: "Standard" }
        };
        const credential = new DefaultAzureCredential();
        const client = new NetworkManagementClient(credential, subscriptionId);
        const result = yield client.loadBalancers.beginCreateOrUpdateAndWait(resourceGroupName, loadBalancerName, parameters);
        console.log(result);
    });
}
createLoadBalancerWithOutboundRules().catch(console.error);
//# sourceMappingURL=loadBalancersCreateOrUpdateSample.js.map